==> jc-1.4.0.tar.gz: javax/print/attribute/standard/Media.h <==
// public abstract class javax.print.attribute.standard.Media

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class ab3220e6946f401b javax_print_attribute_standard_Media

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_Media_H_
#define _JC_javax_print_attribute_standard_Media_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Media$sub_refs	_jc_javax_print_attribute_standard_Media$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Media$sub_nonrefs	_jc_javax_print_attribute_standard_Media$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Media$refs	_jc_javax_print_attribute_standard_Media$refs;
typedef struct _jc_javax_print_attribute_standard_Media$nonrefs	_jc_javax_print_attribute_standard_Media$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Media$object	_jc_javax_print_attribute_standard_Media$object;

typedef struct _jc_javax_print_attribute_standard_Media$fields_struct	_jc_javax_print_attribute_standard_Media$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Media$vmethods	_jc_javax_print_attribute_standard_Media$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Media$vtable	_jc_javax_print_attribute_standard_Media$vtable;
typedef const struct _jc_javax_print_attribute_standard_Media$vtype	_jc_javax_print_attribute_standard_Media$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Media$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Media;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Media$fields_struct _jc_javax_print_attribute_standard_Media$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Media$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Media$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Media$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Media$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Media$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Media$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Media$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_Media$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Media$vmethods	javax_print_attribute_standard_Media;
};

// Vtype
struct _jc_javax_print_attribute_standard_Media$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Media$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Media$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Media$refs {
    _jc_javax_print_attribute_standard_Media$sub_refs	javax_print_attribute_standard_Media;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Media$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Media$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Media$sub_nonrefs	javax_print_attribute_standard_Media;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Media$object {
	_jc_javax_print_attribute_standard_Media$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Media$vtype	*vtype;
	_jc_javax_print_attribute_standard_Media$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Media$vtype _jc_javax_print_attribute_standard_Media$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Media, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Media$class_object;

#endif	/* _JC_javax_print_attribute_standard_Media_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/Media.h <==
// public abstract class javax.print.attribute.standard.Media

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class ab3220e6946f401b javax_print_attribute_standard_Media

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_Media_H_
#define _JC_javax_print_attribute_standard_Media_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Media$sub_refs	_jc_javax_print_attribute_standard_Media$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Media$sub_nonrefs	_jc_javax_print_attribute_standard_Media$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Media$refs	_jc_javax_print_attribute_standard_Media$refs;
typedef struct _jc_javax_print_attribute_standard_Media$nonrefs	_jc_javax_print_attribute_standard_Media$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Media$object	_jc_javax_print_attribute_standard_Media$object;

typedef struct _jc_javax_print_attribute_standard_Media$fields_struct	_jc_javax_print_attribute_standard_Media$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Media$vmethods	_jc_javax_print_attribute_standard_Media$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Media$vtable	_jc_javax_print_attribute_standard_Media$vtable;
typedef const struct _jc_javax_print_attribute_standard_Media$vtype	_jc_javax_print_attribute_standard_Media$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Media$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Media;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Media$fields_struct _jc_javax_print_attribute_standard_Media$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Media$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Media$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Media$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Media$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Media$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Media$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Media$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Media$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_Media$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Media$vmethods	javax_print_attribute_standard_Media;
};

// Vtype
struct _jc_javax_print_attribute_standard_Media$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Media$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Media$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Media$refs {
    _jc_javax_print_attribute_standard_Media$sub_refs	javax_print_attribute_standard_Media;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Media$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Media$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Media$sub_nonrefs	javax_print_attribute_standard_Media;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Media$object {
	_jc_javax_print_attribute_standard_Media$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Media$vtype	*vtype;
	_jc_javax_print_attribute_standard_Media$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Media$vtype _jc_javax_print_attribute_standard_Media$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Media, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Media$class_object;

#endif	/* _JC_javax_print_attribute_standard_Media_H_ */
